@@ -224,7 +224,9 @@ and find_read_thf_file dir f =
 	  find_read_thf_file_r dir dir f
       with
       | Not_found -> find_read_thf_file_r dir dir f
-    end
+    end;;
+
+st_find_read_thf_fun := find_read_thf_file;;
 
 (*** If the slave got a final result, then use it. ***)
 let handle_slave_return pstatus =
