@@ -64,6 +64,13 @@ let minimal_unsatisfiable_core clauses =
 	with
 	| End_of_file ->
 	    ignore (Unix.close_process_full (myout,myin,myerr));
+	    if (!verbosity > 4) then
+	      begin
+		Printf.printf "Minimized Clause Set\n";
+		List.iter
+		  (fun cl -> List.iter (fun l -> Printf.printf "%d " l) cl; Printf.printf "\n")
+		  (!ret)
+	      end;
 	    (!ret)
       end
   | _ -> raise (GenericError "strange return from picomus") (*** In case this happens, maybe I should just return all the clauses ***)
@@ -1515,7 +1522,7 @@ exception ExistsToChoiceDone
 
 let rec existstochoice1 m p =
   match m with
-  | Ap(Forall(a),m1) -> (*** to do ***)
+  | Ap(Forall(a),m1) ->
       let q = gen_lam_body a m1 in
       begin
 	if p then
